==> nextcloud-22.2.10.tgz: nextcloud/apps/notifications/l10n/zh_HK.js <==
OC.L10N.register(
    "notifications",
    {
    "Hello %s" : "%s 你好",
    "Hello %s," : "%s你好，",
    "_New notification for %s_::_%n new notifications for %s_" : ["%s 有 %n 個新通知"],
    "_You have a new notification for %s_::_You have %n new notifications for %s_" : ["您有 %n 個關於 %s 的新通知"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "您可在<a href=\"%s\">設定</a>中更改通知電郵的接收次數或停用。",
    "You can change the frequency of these emails or disable them in the settings: %s" : "您可在設定中更改這些電郵地址的頻率或停用：%s",
    "Admin notifications" : "管理員通告",
    "Notifications" : "通告",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "此應用程式為 Nextcloud 中提供的通告 API 提供了前後端。",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "此應用程式為 Nextcloud 中提供的通告 API 提供了前後端。\n\t\t其他應用程式使用這個 API 來通告在 Web UI 中的用戶，並同步客戶端。這裡有一些例子：\n\n📬 聯盟檔案分享：您收到了新的遠端分享\n\n📑 留言：其他用戶在檔案中的留言提及您\n\n🚢 更新通告：應用程式或 Nextcloud 自身有可用的更新\n\n📣 公告中心：管理員發佈了公告",
    "Failed to perform action" : "無法執行操作",
    "Dismiss" : "撤銷",
    "seconds ago" : "幾秒前",
    "Failed to dismiss notification" : "撤銷通告失敗",
    "in {path}" : "在 {path}",
    "Dismiss all notifications" : "撤銷所有通告",
    "Requesting browser permissions to show notifications" : "需要瀏覽器權限以顯示通告",
    "No notifications" : "沒有通告",
    "Failed to dismiss all notifications" : "撤銷所有通告失敗",
    "You need to set up your email address before you can receive notification emails." : "您必須先設定電郵地址，才能接收通知。",
    "Send email reminders about unhandled notifications after:" : "發送有關未處理通知的電郵提醒：",
    "Play sound when a new notification arrives" : "收到新通知時播放聲音",
    "Play sound when a call started (requires Nextcloud Talk)" : "通話開始時播放聲音（需要 Nextcloud Talk）",
    "Never" : "從不",
    "1 hour" : "1 小時",
    "3 hours" : "3 小時",
    "1 day" : "1 日",
    "1 week" : "1 個星期",
    "Your settings have been updated." : "您的設定已更新。",
    "An error occurred while updating your settings." : "更新設置時發生錯誤"
},
"nplurals=1; plural=0;");

==> nextcloud-23.0.3.tgz: nextcloud/apps/notifications/l10n/zh_HK.js <==
OC.L10N.register(
    "notifications",
    {
    "Hello %s" : "%s 你好",
    "Hello %s," : "%s你好，",
    "_New notification for %s_::_%n new notifications for %s_" : ["%s 有 %n 個新通知"],
    "_You have a new notification for %s_::_You have %n new notifications for %s_" : ["您有 %n 個關於 %s 的新通知"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "您可在<a href=\"%s\">設定</a>中更改這些電郵的頻率或停用。",
    "You can change the frequency of these emails or disable them in the settings: %s" : "您可在設定中更改這些電郵地址的頻率或停用：%s",
    "Admin notifications" : "管理員通告",
    "Notifications" : "通告",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "此應用程式為 Nextcloud 中提供的通告 API 提供了前後端。",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "此應用程式為 Nextcloud 中提供的通告 API 提供了前後端。\n\t\t其他應用程式使用這個 API 來通告在 Web UI 中的用戶，並同步客戶端。這裡有一些例子：\n\n📬 聯盟檔案分享：您收到了新的遠端分享\n\n📑 留言：其他用戶在檔案中的留言提及您\n\n🚢 更新通告：應用程式或 Nextcloud 自身有可用的更新\n\n📣 公告中心：管理員發佈了公告",
    "Dismiss all notifications" : "撤銷所有通告",
    "Requesting browser permissions to show notifications" : "需要瀏覽器權限以顯示通告",
    "No notifications" : "沒有通告",
    "Failed to dismiss all notifications" : "撤銷所有通告失敗",
    "Failed to perform action" : "無法執行操作",
    "Dismiss" : "撤銷",
    "seconds ago" : "幾秒前",
    "Failed to dismiss notification" : "撤銷通告失敗",
    "in {path}" : "在 {path}",
    "You need to set up your email address before you can receive notification emails." : "您必須先設定電郵地址，才能接收通知。",
    "Send email reminders about unhandled notifications after:" : "發送有關未處理通知的電郵提醒：",
    "Never" : "從不",
    "1 hour" : "1 小時",
    "3 hours" : "3 小時",
    "1 day" : "1 日",
    "1 week" : "1 個星期",
    "Your settings have been updated." : "您的設定已更新。",
    "An error occurred while updating your settings." : "更新設置時發生錯誤"
},
"nplurals=1; plural=0;");
